@@ -176,6 +176,11 @@ func Test_NamespaceForDistro(t *testing.T) {
 			version:  "8.5",
 			expected: "rhel:8",
 		},
+		{
+			dist:     distro.Gentoo,
+			version:  "", // Gentoo doesn't expose a version
+			expected: "gentoo:",
+		},
 	}
 
 	observedDistros := strset.New()
@@ -325,6 +330,19 @@ func Test_NamespacesForLanguage(t *testing.T) {
 				"a-name",
 			},
 		},
+		{
+			language: syftPkg.Haskell,
+			namerInput: &pkg.Package{
+				ID:   pkg.ID(uuid.NewString()),
+				Name: "h-name",
+			},
+			expectedNamespaces: []string{
+				"github:haskell",
+			},
+			expectedNames: []string{
+				"h-name",
+			},
+		},
 	}
 
 	observedLanguages := strset.New()
